@@ -22,7 +22,6 @@ import tim.prune.function.autoplay.AutoplayFunction;
 import tim.prune.function.charts.Charter;
 import tim.prune.function.compress.CompressTrackFunction;
 import tim.prune.function.compress.DeleteMarkedPointsFunction;
-import tim.prune.function.compress.MarkLiftsFunction;
 import tim.prune.function.compress.MarkPointsInRectangleFunction;
 import tim.prune.function.deletebydate.DeleteByDateFunction;
 import tim.prune.function.distance.DistanceFunction;
@@ -91,11 +90,11 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_CREATE_MARKER_WAYPOINTS = null;
 	public static GenericFunction FUNCTION_REARRANGE_PHOTOS = null;
 	public static GenericFunction FUNCTION_COMPRESS = null;
-	public static GenericFunction FUNCTION_MARK_LIFTS = null;
 	public static DeleteMarkedPointsFunction FUNCTION_DELETE_MARKED_POINTS = null;
 	public static GenericFunction FUNCTION_DELETE_RANGE = null;
 	public static GenericFunction FUNCTION_CROP_TRACK = null;
-	public static GenericFunction FUNCTION_MARK_IN_RECTANGLE = null;
+	public static GenericFunction FUNCTION_MARK_INSIDE_RECTANGLE = null;
+	public static GenericFunction FUNCTION_MARK_OUTSIDE_RECTANGLE = null;
 	public static GenericFunction FUNCTION_DELETE_BY_DATE = null;
 	public static SingleNumericParameterFunction FUNCTION_INTERPOLATE = null;
 	public static GenericFunction FUNCTION_LOOKUP_SRTM = null;
@@ -172,11 +171,11 @@ public abstract class FunctionLibrary
 		FUNCTION_CREATE_MARKER_WAYPOINTS = new CreateMarkerWaypointsFunction(inApp);
 		FUNCTION_REARRANGE_PHOTOS = new RearrangePhotosFunction(inApp);
 		FUNCTION_COMPRESS = new CompressTrackFunction(inApp);
-		FUNCTION_MARK_LIFTS = new MarkLiftsFunction(inApp);
 		FUNCTION_DELETE_MARKED_POINTS = new DeleteMarkedPointsFunction(inApp);
 		FUNCTION_DELETE_RANGE = new DeleteSelectedRangeFunction(inApp);
 		FUNCTION_CROP_TRACK = new CropToSelection(inApp);
-		FUNCTION_MARK_IN_RECTANGLE = new MarkPointsInRectangleFunction(inApp);
+		FUNCTION_MARK_INSIDE_RECTANGLE = new MarkPointsInRectangleFunction(inApp, true);
+		FUNCTION_MARK_OUTSIDE_RECTANGLE = new MarkPointsInRectangleFunction(inApp, false);
 		FUNCTION_DELETE_BY_DATE = new DeleteByDateFunction(inApp);
 		FUNCTION_INTERPOLATE = new InterpolateFunction(inApp);
 		FUNCTION_LOOKUP_SRTM = new LookupSrtmFunction(inApp);
