@@ -25,7 +25,7 @@ public class EditSingleFieldCmd extends Command
 	}
 
 	protected EditSingleFieldCmd(EditSingleFieldCmd inParent, Field inField,
-			List<PointEdit> inEditList, UnitSet inUnitSet)
+		List<PointEdit> inEditList, UnitSet inUnitSet)
 	{
 		super(inParent);
 		_field = inField;
@@ -48,6 +48,9 @@ public class EditSingleFieldCmd extends Command
 		for (PointEdit edit : _editList) {
 			inInfo.getTrack().getPoint(edit.getPointIndex()).setFieldValue(_field, edit.getValue(), _unitSet, isUndo());
 		}
+		if (_field == Field.LATITUDE || _field == Field.LONGITUDE) {
+			inInfo.getTrack().requestRescale();
+		}
 		return true;
 	}
 
