@@ -15,17 +15,14 @@ public abstract class Maths
 		if (Math.abs(a) > Math.abs(b))
 		{
 			r = b/a;
-			r = Math.abs(a)*Math.sqrt(1+r*r);
+			return Math.abs(a)*Math.sqrt(1+r*r);
 		}
 		else if (b != 0)
 		{
 			r = a/b;
-			r = Math.abs(b)*Math.sqrt(1+r*r);
+			return Math.abs(b)*Math.sqrt(1+r*r);
 		}
-		else
-		{
-			r = 0.0;
-		}
-		return r;
+		// b is zero and a isn't bigger than b
+		return 0.0;
 	}
 }
