@@ -4,6 +4,8 @@ import java.awt.BorderLayout;
 import java.awt.Component;
 import java.awt.Dimension;
 import java.awt.FlowLayout;
+import java.awt.event.KeyAdapter;
+import java.awt.event.KeyEvent;
 import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
 import java.util.ArrayList;
@@ -17,15 +19,16 @@ import javax.swing.JScrollPane;
 import javax.swing.JSplitPane;
 import javax.swing.JTable;
 import javax.swing.JTextArea;
+import javax.swing.SwingUtilities;
 
 import tim.prune.App;
 import tim.prune.GenericFunction;
 import tim.prune.I18nManager;
 import tim.prune.cmd.AppendRangeCmd;
 import tim.prune.data.DataPoint;
-import tim.prune.data.Field;
 import tim.prune.data.Latitude;
 import tim.prune.data.Longitude;
+import tim.prune.data.Unit;
 import tim.prune.function.browser.BrowserLauncher;
 
 /**
@@ -52,6 +55,8 @@ public abstract class GenericDownloaderFunction extends GenericFunction implemen
 	private JButton _loadButton = null;
 	/** Show button */
 	private JButton _showButton = null;
+	/** Cancel button */
+	private JButton _cancelButton = null;
 
 
 	/**
@@ -94,6 +99,7 @@ public abstract class GenericDownloaderFunction extends GenericFunction implemen
 
 		// Show dialog
 		_dialog.setVisible(true);
+		_cancelButton.requestFocus();
 	}
 
 
@@ -110,7 +116,8 @@ public abstract class GenericDownloaderFunction extends GenericFunction implemen
 		_statusLabel = new JLabel(I18nManager.getText("confirm.running"));
 		dialogPanel.add(_statusLabel, BorderLayout.NORTH);
 		// Main panel with track list
-		_trackListModel = new TrackListModel(getColumnKey(0), getColumnKey(1));
+		Unit distUnit = getConfig().getUnitSet().getDistanceUnit();
+		_trackListModel = new TrackListModel(getColumnKey(0), getColumnKey(1), distUnit);
 		_trackTable = new JTable(_trackListModel);
 		_trackTable.getSelectionModel().addListSelectionListener(e -> {
 			if (!e.getValueIsAdjusting()) {
@@ -151,12 +158,14 @@ public abstract class GenericDownloaderFunction extends GenericFunction implemen
 		_showButton.setEnabled(false);
 		_showButton.addActionListener(e -> showSelectedWebpage());
 		buttonPanel.add(_showButton);
-		JButton cancelButton = new JButton(I18nManager.getText("button.cancel"));
-		cancelButton.addActionListener(e -> {
-			_cancelled = true;
-			_dialog.dispose();
+		_cancelButton = new JButton(I18nManager.getText("button.cancel"));
+		_cancelButton.addActionListener(e -> cancel());
+		_cancelButton.addKeyListener(new KeyAdapter() {
+			public void keyPressed(KeyEvent inE) {
+				if (inE.getKeyCode() == KeyEvent.VK_ESCAPE) {cancel();}
+			}
 		});
-		buttonPanel.add(cancelButton);
+		buttonPanel.add(_cancelButton);
 		dialogPanel.add(buttonPanel, BorderLayout.SOUTH);
 		dialogPanel.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 15));
 		return dialogPanel;
@@ -199,11 +208,17 @@ public abstract class GenericDownloaderFunction extends GenericFunction implemen
 		_descriptionBox.setText(text);
 	}
 
+	/** Cancel and close the dialog */
+	private void cancel()
+	{
+		_cancelled = true;
+		_dialog.dispose();
+	}
 
 	/**
 	 * Load the selected point(s)
 	 */
-	private final void loadSelected()
+	private void loadSelected()
 	{
 		// Find the rows selected in the table and get the corresponding coords
 		int numSelected = _trackTable.getSelectedRowCount();
@@ -219,8 +234,8 @@ public abstract class GenericDownloaderFunction extends GenericFunction implemen
 				String lon = _trackListModel.getTrack(rowNum).getLongitude();
 				if (lat != null && lon != null)
 				{
-					DataPoint point = new DataPoint(new Latitude(lat), new Longitude(lon), null);
-					point.setFieldValue(Field.WAYPT_NAME, _trackListModel.getTrack(rowNum).getTrackName(), false);
+					DataPoint point = new DataPoint(Latitude.make(lat), Longitude.make(lon));
+					point.setWaypointName(_trackListModel.getTrack(rowNum).getTrackName());
 					points.add(point);
 				}
 			}
@@ -252,4 +267,9 @@ public abstract class GenericDownloaderFunction extends GenericFunction implemen
 		}
 		// Don't close the dialog
 	}
+
+	/** Respond to the completion of the search from a subclass's separate thread */
+	protected void finishedSearch() {
+		SwingUtilities.invokeLater(() -> _cancelButton.requestFocus());
+	}
 }
