@@ -41,14 +41,14 @@ public class SetLanguage extends GenericFunction
 
 	/** Names of languages for display in dropdown (not translated) */
 	private static final String[] LANGUAGE_NAMES = {"afrikaans", "catal\u00e0", "\u010de\u0161tina", "deutsch",
-		"english", "american english", "espa\u00F1ol", "fran\u00E7ais", "italiano", "magyar", "nederlands",
-		"norsk", "polski", "portugu\u00EAs", "rom\u00E2n\u0103", "suomi", "svenska",
+		"english", "american english", "espa\u00f1ol", "fran\u00e7ais", "italiano", "magyar", "nederlands",
+		"norsk bokm\u00e5l", "polski", "portugu\u00eas", "rom\u00e2n\u0103", "suomi", "svenska",
 		"\u0440\u0443\u0441\u0441\u043a\u0438\u0439 (russian)", "\u4e2d\u6587 (chinese)",
-		"\u65E5\u672C\u8A9E (japanese)", "\uD55C\uAD6D\uC5B4/\uC870\uC120\uB9D0 (korean)", "schwiizerd\u00FC\u00FCtsch"
+		"schwiizerd\u00fc\u00fctsch"
 	};
 	/** Associated language codes (must be in same order as names!) */
 	private static final String[] LANGUAGE_CODES = {"af", "ca", "cz", "de", "en", "en_us", "es", "fr", "it", "hu",
-		"nl", "no", "pl", "pt", "ro", "fi", "sv", "ru", "zh", "ja", "ko", "de_ch"
+		"nl", "no", "pl", "pt", "ro", "fi", "sv", "ru", "zh", "de_ch"
 	};
 
 
@@ -289,7 +289,7 @@ public class SetLanguage extends GenericFunction
 	{
 		JFileChooser chooser = new JFileChooser();
 		chooser.addChoosableFileFilter(
-			new GenericFileFilter("filetype.txt", new String[] {"txt", "text"}));
+			new GenericFileFilter("filetypefilter.txt", new String[] {"txt", "text"}));
 		chooser.setAcceptAllFileFilterUsed(true);
 		// Set start path from currently selected file
 		String currPath = _langFileBox.getText();
