@@ -17,10 +17,12 @@ public class SegmentColourer extends DiscretePointColourer
 	 * @param inStartColour start colour of scale
 	 * @param inEndColour end colour of scale
 	 * @param inWrapLength number of unique colours before wrap
+	 * @param inWideHues true for wide mode, false for narrow
 	 */
-	public SegmentColourer(Color inStartColour, Color inEndColour, int inWrapLength)
+	public SegmentColourer(Color inStartColour, Color inEndColour,
+		int inWrapLength, boolean inWideHues)
 	{
-		super(inStartColour, inEndColour, inWrapLength);
+		super(inStartColour, inEndColour, inWrapLength, inWideHues);
 	}
 
 	/**
