@@ -8,6 +8,6 @@ public class JpegFileFilter extends GenericFileFilter
 	/** Constructor */
 	public JpegFileFilter()
 	{
-		super("filetype.jpeg", new String[] {"jpg", "jpe", "jpeg"});
+		super("filetypefilter.jpeg", new String[] {"jpg", "jpe", "jpeg"});
 	}
 }
