@@ -15,10 +15,14 @@ public class GpxTag
 		_value = inVal;
 	}
 
+	public void clear() {
+		setValue("");
+	}
+
 	/**
 	 * @return value
 	 */
 	public String getValue() {
-		return _value;
+		return _value == null ? "" : _value.trim();
 	}
 }
