@@ -41,16 +41,9 @@ public abstract class WindowFactory
 			Class<?> universeClass = Class.forName("com.sun.j3d.utils.universe.SimpleUniverse");
 			has3d = (universeClass != null);
 		}
-		catch (ClassNotFoundException e)
-		{
+		catch (ClassNotFoundException | NoClassDefFoundError e) {
 			// no java3d classes available
-		}
-		catch (NoClassDefFoundError nfe)
-		{
-			// no java3d classes available
-		}
-		catch (UnsatisfiedLinkError ule)
-		{
+		} catch (UnsatisfiedLinkError ule) {
 			// java3d classes found but no native components
 		}
 		return has3d;
